*******************************************************************************;
**This is ~/sic/contrib_output.sas                                           **;
**The input files are ~/sic/rawdata/contribution/SIC_2DIGIT_ANNUAL_89to91.TXT**;
**  SIC_2DIGIT_ANNUAL_92to98.TXT and sitc_priceindex_89to99.txt,             **;
**  ~/sic/rawdata/SITC_2digit_ForIndex/SITC_2DIGIT_ANNUAL_95.TXT and         **;
**  ~/sic/rawdata/output/go8796.dat                                          **;
**This program creates the "real" export effect of growth from 1990 to 1996  **;
**  in Table 7 (last 2 columns) of the Pollard/Coughlin Review article       **;
**Right now the export levels and export price indices have data through 1998**;
**     The gross output data only goes through 1996.  When new output data is**;
**     available change the top part of the program the pulls in the data    **;
**     and extend the var lists at the very end of the program to incorporate**;
**     the 1997 data.                                                        **;
*******************************************************************************;
**************************************;
**                                  **;
**PULL IN GROSS OUTPUT DATA FROM BEA**;
**                                  **;
**************************************;
filename in '/users2/h1hlb00/sic/rawdata/output';
libname out '/users2/h1hlb00/sic/rawdata';
options linesize=150 pagesize=58;
***********************;
**  CURRENT DOLLAR   **;
***********************;
data current;
  infile in(go8796.dat) firstobs=2 obs=238 pad;
  input @1 type $1. @3 sic $17. @21 desc $90. @126 nout87-nout95  @209 nout96 6. ;
*GET RID OF BLANK SPACES BROOGHT IN WITH VAR SIC;
  sic=compress(sic);
*KEEP ONLY THE SIC CODES WITH EXPORT LEVELS TO CORRESPOND;
  if (sic) in("01&02","07-09","10","11-12","13","14","20","21","22","23","24",
                      "25","26","27","28","29","30","31","32","33","34","35","36",
                      "371","37except371","38","39");
*KEEP CURRENT DOLLAR DATA;
  if type="A";
run;
**********************;
**  CONSTANT DOLLAR **;
**********************;
data constant;
  infile in(go8796.dat) firstobs=240 pad obs=437;
  input @1 type $1. @3 sic $17. @21 desc $90. @126 rout87-rout95 @209 rout96 6.;
*GET RID OF BLANK SPACES BROUGHT IN WITH VAR SIC;
  sic=compress(sic);
*KEEP ONLY THE SIC CODES WITH EXPORT LEVELS TO CORRESPOND;
  if (sic) in("01&02","07-09","10","11-12","13","14","20","21","22","23","24",
                      "25","26","27","28","29","30","31","32","33","34","35","36",
                      "371","37except371","38","39");
*KEEP CONSTANT DOLLAR DATA;
  if type="B";
run;

***************************;
**MAKE SIC CATEGORIES 37 **;
**  CURRENT DOLLAR       **;
***************************;
data chngsic;
  set current(where=((sic) in("371","37except371")));
run;
proc transpose data=chngsic out=newvar;
 id sic;
run;
data newvar;
 set newvar;
 *SIC37 = SIC371 PLUS SIC37 EXCEPT FOR 371;
   _37=_37EXCEP+_371;
run;
proc transpose data=newvar out=chngsic; run;
data chngsicn; set chngsic;
 *REMOVE SIC371 and SIC37X AS THEY ARE NOT NEEDED ANYMORE;
   if compress(_NAME_) in("_371","_37EXCEP") then delete;
 *CHANGE THE SIC NAMES BACK TO MATCH THE ORIGINAL NAMES IN THE RAW DATA;
   if compress(_NAME_) = "_37" then _NAME_="37";
 *REMANE TRANSPOSE VAR _NAME_ TO SIC IN ORDER TO MERGE WITH ORIGINAL RAW DATA;
   rename _NAME_=sic;
run;
proc sort data=chngsicn; by sic; run;

***************************;
**MAKE SIC CATEGORIES 37 **;
**  CONSTANT DOLLAR      **;
***************************;
data chngsic;
  set constant(where=((sic) in("371","37except371")));
run;
proc transpose data=chngsic out=newvar;
 id sic;
run;
data newvar;
 set newvar;
 *SIC37 = SIC371 plus SIC37 EXCEPT FOR 371;
   _37=_37EXCEP+_371;
run;
proc transpose data=newvar out=chngsic; run;
data chngsicr; set chngsic;
 *REMOVE SIC371 AND SIC37X AS THEY ARE NOT NEEDED ANYMORE;
   if compress(_NAME_) in("_371","_37EXCEP") then delete;
 *CHANGE THE SIC NAMES BACK TO MATCH THE ORIGINAL NAMES IN THE RAW DATA;
   if compress(_NAME_) = "_37" then _NAME_="37";
 *RENAME TRANSPOSE VAR _NAME_ TO SIC IN ORDER TO MERGE WITH ORIGINAL RAW DATA;
   rename _NAME_=sic;
run;
proc sort data=chngsicr; by sic; run;

proc sort data=current; by sic; run;
proc sort data=constant; by sic; run;
**************************************;
**COMBINE NOMINAL AND REAL DATA     **;
**************************************;
data output;
 merge constant current chngsicn chngsicr;
 by sic;
 *GET RID OF ORIGINAL VARS SIC371 AND SIC37X;
   if sic in("371","37except371") then delete;
 *REASSIGN SIC NUMBERS TO MAKE MERGING WITH EXPORT LEVEL DATA EASIER;
   if sic="07-09" then sic="709";
   if sic="01&02" then sic="102";
   if sic="11-12" then sic="12";
 *MAKE SIC NUMERIC;
   siccode=0+sic;

**************************************;
**CREATE 1992 BASED PRICE DEFLATOR  **;
**************************************;
%macro def92dol;
  %do y=87 %to 97;
    def&y=nout&y/rout&y;
  %end;
  %mend;
%def92dol;

**************************************;
**CREATE 1995 BASED PRICE DEFLATOR  **;
**************************************;
%macro def95dol;
  %do y=87 %to 97;
    d95_&y=def&y/def95;
  %end;
  %mend;
%def95dol;

**************************************;
**CREATE 1995 BASED OUTPUT DATA     **;
**************************************;
%macro real95;
  %do y=87 %to 97;
    r95_&y=nout&y/d95_&y;
  %end;
  %mend;
%real95;
run;

proc sort data=output; by siccode; run;
**************************************;
**PRINT GROSS OUTPUT RAW DATA       **;
**************************************;
proc print;
  var siccode nout89-nout96;
  *var siccode nout89-nout97;
  title "Nominal Gross Output";
run;
proc print;
  var siccode rout89-rout96;
  *var siccode rout89-rout97;
  title "1992$ Real Gross Output";
run;
proc print;
  var siccode  def89-def96 ;
  *var siccode  def89-def97;
  title "1992 Price Deflator for Gross Output";
run;
proc print;
  var siccode  d95_89-d95_96;
  *var siccode  d95_89-d95_97;
  title "1995 Price Deflator for Gross Output";
run;
proc print;
  var siccode   r95_89-r95_96;
  *var siccode  r95_89-r95_97;
  title "1995$ Real Gross Output";
run;

***********************************************;
**                                           **;
**PULL IN NOMINAL EXPORT LEVELS FROM US/ITC  **;
**                                           **;
***********************************************;
******************************************************************************;
**Remember to change Hong Kong to Hong_Kong in the export level data files!!**;
******************************************************************************;
filename in '/users2/h1hlb00/sic/rawdata/contribution';
libname out '/users2/h1hlb00/sic/rawdata';
data data8991;
  infile in(SIC_2DIGIT_ANNUAL_89to91.TXT) firstobs=3 dlm=",";
  input country $ siccode x_y89-x_y91;
run;
data data9298;
  infile in(SIC_2DIGIT_ANNUAL_92to98.TXT) firstobs=3 dlm=",";
  input country $ siccode x_y92-x_y98;
run;

proc sort data=data8991; by country siccode; run;
proc sort data=data9298; by country siccode; run;

data datain;
  merge data8991 data9298;
  by country siccode;
run;

proc sort data=datain; by country; run;
* *************************;
**COMBINE SIC01 and SIC02**;
***************************;
proc means data=datain(where=(siccode in(1,2))) sum noprint;
 var x_y89-x_y98;
 by country;
 output out=_12 sum=;
run;
*******************************;
**COMBINE SIC07, SIC08, SIC09**;
*******************************;
proc means data=datain(where=(siccode in(7,8,9))) sum noprint;
 var x_y89-x_y98;
 by country;
 output out=_79 sum=;
run;

****************************************;
**GIVE COMBO SIC CODE FOR ABOVE GROUPS**;
****************************************;
data datain;
  set datain
      _12(in=sic0102)
      _79(in=sic0709);
if sic0102=1 then siccode=102;
if sic0709=1 then siccode=709;
**DELETE UNUSED SIC CODES;
  if siccode in(91,92,99) then delete;
run;

****************************************;
**MAKE ASIAN 10 EXPORT LEVEL - NOMINAL**;
****************************************;
proc sort data=datain; by siccode; run;
proc means data=datain sum noprint;
 var x_y89-x_y98;
 by siccode;
 output out=export sum=;
run;
proc print;
 var siccode x_y89-x_y98;
 title "Nominal Asian 10 Export Levels";
 footnote " ";
run;

****************************************************;
**                                                **;
**MAKE THE EXPORT PRICE INDEXES USED IN THIS PAPER**;
**                                                **;
****************************************************;
**                                        **;
**PULL IN THE EXPORT PRICE LEVELS FROM BLS**;
**                                        **;
********************************************;
**REMEMBER:  In sitc_priceindex_89to99.txt**;
**           Change:  "n.a." to "."       **;
**           Change:  ": No data" to " "  **;
********************************************;
filename in '/users2/h1hlb00/sic/rawdata/contribution';
filename in2 '/users2/h1hlb00/sic/rawdata/SITC_2digit_ForIndex';
filename in3 '/users2/h1hlb00/sic/rawdata';
data x_price(drop=_89m1-_89m12
                  _90m1-_90m12
                  _91m1-_91m12
                  _92m1-_92m12
                  _93m1-_93m12
                  _94m1-_94m12
                  _95m1-_95m12
                  _96m1-_96m12
                  _97m1-_97m12
                  _98m1-_98m12);
  infile in(sitc_priceindex_89to99.txt) linesize=1000 firstobs=305 dlm="," ;
  input seriesid $
                   _89m1  _89m2  _89m3  _89m4   _89m5   _89m6
                   _89m7  _89m8  _89m9  _89m10  _89m11  _89m12  ann89
                   _90m1  _90m2  _90m3  _90m4   _90m5   _90m6
                   _90m7  _90m8  _90m9  _90m10  _90m11  _90m12  ann90
                   _91m1  _91m2  _91m3  _91m4   _91m5   _91m6
                   _91m7  _91m8  _91m9  _91m10  _91m11  _91m12  ann91
                   _92m1  _92m2  _92m3  _92m4   _92m5   _92m6
                   _92m7  _92m8  _92m9  _92m10  _92m11  _92m12  ann92
                   _93m1-_93m12 ann93
                   _94m1-_94m12 ann94
                   _95m1-_95m12 ann95
                   _96m1-_96m12 ann96
                   _97m1-_97m12 ann97
                   _98m1-_98m12 ann98 ;
*CHANGE 1999 MISSING VALUES FROM No Data TO .;
  %macro strange;
    %do y = 89 %to 98;
    %do i = 1 %to 12;
       if _&y.m&i>=1989 then _&y.m&i=.;
    %end;
    %end;
    %mend;
  %strange;
*GET RID OF ANNUAL VALUES;
  drop ann89 ann90 ann91 ann92 ann93 ann94 ann95 ann96 ann97 ann98;

length sitccode 3.;
************************************************************;
**MAKE 2 DIGIT SITC CODES FOR THE MAJOR INDUSTRY GROUPINGS**;
************************************************************;
  if compress(seriesid)="EIUIE1" then sitccode=1*10;
   else if compress(seriesid)="EIUIE2" then sitccode=2*10;
   else if compress(seriesid)="EIUIE3" then sitccode=3*10;
   else if compress(seriesid)="EIUIE4" then sitccode=4*10;
   else if compress(seriesid)="EIUIE5" then sitccode=5*10;
   else if compress(seriesid)="EIUIE6" then sitccode=6*10;
   else if compress(seriesid)="EIUIE7" then sitccode=7*10;
   else if compress(seriesid)="EIUIE8" then sitccode=8*10;
   else if compress(seriesid)="EIUIE9" then sitccode=9*10;
************************************************************;
**"OTHER" INDUSTRY GROUPINGS NOT USED IN THESE CALCULATIONS*;
************************************************************;
   else if compress(seriesid)="EIUIE0R" then delete;
   else if compress(seriesid)="EIUIE2R" then delete;
   else if compress(seriesid)="EIUIE8R" then delete;
**************************************************************;
**MAKE SITC CODE OUT OF THE LAST 2 DIGITS OF THE BLS MNEMONIC*;
**************************************************************;
   else sitccode = substr(seriesid,6,3);

**************************************************************;
**CREATE ANNUAL AND QUARTERLY AVERAGES FROM RAW MONTHLY DATA**;
**************************************************************;
%macro chngfreq;
  %do i = 89 %to 98;
    **Create annual averages of available data;
    y&i=mean(of _&i.m1-_&i.m12);
  %end;
  %mend;
%chngfreq;
if sitccode in(2,6,7,11,23,29,34,41,42,43,52,53,56,58,61,63,67,79,81,83,84,85) then delete;
run;

**************************************;
**PRINT RAW EXPORT PRICE INDEX DATA **;
**************************************;
proc print;
 var sitccode y89-y98;
 title "SITC Export Price Indices";
 footnote " ";
run;

********************************************;
**                                        **;
**PULL IN THE 1995 EXPORT LEVELS FROM ITC **;
**                                        **;
********************************************;
**Use 1995 because the export prices have **;
**  a 1995 base period.                   **;
********************************************;
data x_levels(drop=sitccode);
  infile in2(SITC_2DIGIT_ANNUAL_95.TXT) firstobs=3 dlm="," pad;
  input sitccode x95level;

*CREATE GROUPS FOR CHANGING SITC INTO SIC WHERE THERE IS NO DIRECT MATCH BETWEEN THEM;
  if sitccode in(0,2,4,5,21,22) then group1=x95level;
  if sitccode in(1,2,3,4,5,6,7,8,9,11,29,41,42,43) then group2=x95level;
  if sitccode in(23,62) then group3=x95level;
  if sitccode in(24,63,81) then group4=x95level;
  if sitccode in(25,64) then group5=x95level;
  if sitccode in(26,65) then group6=x95level;
  if sitccode in(51,52,53,54,55,56,57,58,59) then group7=x95level;
  if sitccode in(61,83,85) then group8=x95level;
  if sitccode in(67,68) then group9=x95level;
  if sitccode in(71,72,73,74,75) then group10=x95level;
  if sitccode in(76,77) then group11=x95level;
  if sitccode in(78,79) then group12=x95level;
  if sitccode in(87,88) then group13=x95level;

*ASSIGN SITC CODES TO USE FOR INDUSTRIES WHERE THERE IS NO 2-DIGIT SITC EXPORT PRICE INDEX;
  if sitccode in(0,2,6,7) then sitc_new=0;
   else if sitccode in(11) then sitc_new=10;
   else if sitccode in(23,29) then sitc_new=20;
   else if sitccode in(34) then sitc_new=30;
   else if sitccode in(41,42,43) then sitc_new=40;
   else if sitccode in(52,53,56,57,58) then sitc_new=50;
   else if sitccode in(61,63,67) then sitc_new=60;
   else if sitccode in(79) then sitc_new=70;
   else if sitccode in(81,83,84,85) then sitc_new=80;
   else sitc_new=sitccode;
 sitc_old=sitccode;
run;

********************************************;
**CREATE EXPORT LEVELS FOR GROUPS WITH NO **;
**  SITC=SIC DIRECT MATCH                 **;
********************************************;
proc means data=x_levels sum ;
 var group1-group13;
 output out=grplevel sum=;
     title "1995 Export Levels by Groups of SITCs";
run;

********************************************;
**COMBINE GROUP LEVELS AND INDIVID LEVELS **;
********************************************;
data x_levels;
 if _n_=1 then set grplevel;
 set x_levels(keep=sitc_old sitc_new x95level);
run;
proc print data=x_levels;
 var sitc_old sitc_new x95level;
 title "1995 Export Levels by SITC Code";
run;

proc sort data=x_price; by sitccode; run;
proc sort data=x_levels; by sitc_new; run;
data start;
 merge x_price x_levels(rename=(sitc_new=sitccode));
 by sitccode;

********************************************;
**CREATE SHARE INDEX FOR EACH SITC IN GROUP*;
**SHARE = PRICEINDEX * 1995LEVEL/GROUPLEVEL*;
********************************************;
%macro defgrp(sitcno=,gno=,freq=);
 %do i = 1 %to 54  ;
 %let g=%scan(&gno,&i);
 %let s=%scan(&sitcno,&i);
   %do j=1 %to 10;
   %let f=%scan(&freq,&j);
    if sitc_old = &s then g&g&f=&f*x95level/group&g;
   %end;
 %end;
%mend;
%defgrp(sitcno=0 2 4 5 21 22 1 2 3 4 5 6 7 8 9 11 29 41 42 43 23 62 24 63 81 25 64 26 65 51 52 53
        54 55 56 57 58 59 61 83 85 67 68 71 72 73 74 75 76 77 78 79 87 88,
        gno=1 1 1 1 1 1 2 2 2 2 2 2 2 2 2 2 2 2 2 2 3 3 4 4 4 5 5 6 6 7 7 7 7 7 7 7 7 7 8 8 8 9 9
        10 10 10 10 10 11 11 12 12 13 13,
        freq=y89 y90 y91 y92 y93 y94 y95 y96 y97 y98);
run;

********************************************;
**SUM GROUP SHARES TO CREATE GROUP INDEX  **;
********************************************;
%macro grpindex;
  %do y = 89 %to 98;
    proc means data=start sum;
     var g1y&y g2y&y g3y&y g4y&y g5y&y g6y&y g7y&y g8y&y g9y&y g10y&y g11y&y g12y&y g13y&y;
     output out=defy&y sum=;
     title "19&y Export Price by Groups of SITCs";
    run;
  %end;
  %mend;
%grpindex;

********************************************;
**COMBINE GROUP DATA FROM ALL PERIODS     **;
********************************************;
data groups;
  merge defy89 defy90 defy91 defy92 defy93 defy94 defy95 defy96 defy97 defy98;
run;

***********************************************************;
**MATCH SIC TO SITC INDEXES WHERE THERE IS A DIRECT MATCH**;
***********************************************************;
data sic;
 input siccode sitccode;
 cards;
 1      .
 2      .
 8      3
 9      3
 10     28
 12     32
 13     30
 14     27
 20     .
 21     12
 22     .
 23     80          /*84*/
 24     .
 25     82
 26     .
 27     89
 28     .
 29     33
 30     .
 31     .
 32     66
 33     .
 34     69
 35     .
 36     .
 37     .
 38     .
 39     89
 0102   .
 0709   3
 1112   32
;

proc sort data=sic; by sitccode; run;

*******************************;
**MATCH SITC DIRECTLY TO SIC **;
*******************************;
data index(keep=siccode y89-y98);
  if _n_=1 then set groups;
  merge x_price (keep=sitccode y89 y90 y91 y92 y93 y94 y95 y96 y97 y98)
        sic;
  by sitccode;
%macro tosic(vari=);
  %do i = 1 %to 10;
  %let v = %scan(&vari,&i);

*******************************;
**MATCH SITC GROUPS TO SIC   **;
*******************************;
if sitccode<>"." and siccode<>"." then &v=&v;
  else if siccode in(1,2,102) then &v=g1&v;
  else if siccode in(20) then &v=g2&v;
  else if siccode in(30) then &v=g3&v;
  else if siccode in(24) then &v=g4&v;
  else if siccode in(26) then &v=g5&v;
  else if siccode in(22) then &v=g6&v;
  else if siccode in(28) then &v=g7&v;
  else if siccode in(31) then &v=g8&v;
  else if siccode in(33) then &v=g9&v;
  else if siccode in(35) then &v=g10&v;
  else if siccode in(36) then &v=g11&v;
  else if siccode in(37) then &v=g12&v;
  else if siccode in(38) then &v=g13&v;
  %end;
%mend;
%tosic(vari=y89 y90 y91 y92 y93 y94 y95 y96 y97 y98);
if siccode="." or siccode in(1112,91,92,98,99,0) then delete;
run;

**************************************;
**PRINT "NEW" EXPORT PRICE DEFLATOR **;                  
**************************************;
proc sort data=index; by siccode; run;
proc print;
 var siccode y89-y98;
 title "SIC Export Price Indices (SITC-Based)";
 footnote " ";
run;

************************************************
**                                            **;
**CREATE THE DATA IN LAST 2 COLUMNS OF TABLE 7**;
**                                            **;
************************************************
**************************************;
**DEFLATE THE EXPORT LEVELS FROM ITC**;
**************************************;
data real_x(keep=siccode r_x89-r_x98);
  merge export index;
  by siccode;

%macro real_x;
  %do y = 89 %to 98;
   r_x&y = x_y&y/(y&y/100);
  %end;
%mend;
%real_x;
run;
proc print;
 var siccode r_x89-r_x98;
 title "Real Asian 10 Export Levels";
 footnote " ";
run;

**********************************************************;
**CALCULATE EXPORTS CONTRIBUTION TO OUTPUT GROWTH (REAL)**;
**********************************************************;
data contrib(keep=siccode c90-c98 avg min max);
  merge real_x output;
  by siccode;

%macro real_x;
  %do y = 90 %to 96;
  %let y1 = %eval(&y-1);
   c&y = (((r_x&y-r_x&y1)/1000000)/(r95_&y1))*100;
  %end;
%mend;
%real_x;

avg=mean(of c90-c96);
min=min(of c90-c96);
max=max(of c90-c96);
run;

***********************************;
**PRINT LAST 2 COLUMNS OF TABLE 7**;
***********************************;
proc print;
 var siccode avg min max;
 title "Table 7 - last 2 columns";
 title2 "Export Effect on Growth by Industry - Gross Output Basis";
 title3 "Percent, 1990-96";
 footnote " ";
run;


