*****************************************************************************;
**This is ~/sic/exportchanges_quarterly.sas                                **;
**The input files are ~/sic/rawdata/SIC_2digit/SIC_2DIGIT_QUART_97.txt and **;
**  SIC_2DIGIT_QUART_98.TXT.                                               **;
**The data libraries used are ~/sic/rawdata/xprice.ssd01 and x_out_96.ssd01.**;
**This program creates the "real" changes in export levels that are        **;
**  in Table 5 (Quarter columns).  It also creates the quarterly export    **;
**  effect on gross output shown in Table 7 of the Pollard/Coughlin        **;
**  Review article.                                                        **;
**When new data becomes available change %let goyr= to account for new     **;
**  gross output data and %let yr?= to account for new export level data.  **;
*****************************************************************************;
filename in '/users2/h1hlb00/sic/rawdata/SIC_2digit';
filename in2 '/users2/h1hlb00/sic/rawdata';
libname out '/users2/h1hlb00/sic/rawdata';

%let yr1=97;
%let yr2=98;
%let goyr=96;

**************************************************;
**PULL IN YEAR TO DATE EXPORT LEVELS FROM ITC   **;
**REMEMBER TO CHANGE "Hong Kong" TO "Hong_Kong" **;
**When there is not a complete year of data     **;
**  you will have to change the input line to   **;
**  account for the available data              **;
**************************************************;
data xlevel&yr2;
  infile in(SIC_2DIGIT_QUART_&yr2..TXT) firstobs=3 dlm=",";
  input country $ siccode x_q1&yr2 x_q2&yr2 x_q3&yr2 x_q4&yr2;
run;

proc sort data=xlevel&yr2;
  by country;
run;
***************************;
**COMBINE SIC01 and SIC02**;
***************************;
proc means data=xlevel&yr2(where=(siccode in(1,2))) noprint;
  var x_q1&yr2 x_q2&yr2 x_q3&yr2 x_q4&yr2;
  by country;
  output out=_12_&yr2 sum=;
run;

*********************************;
**COMBINE SIC07,SIC08 AND SIC09**;
*********************************;
proc means data=xlevel&yr2(where=(siccode in(7,8,9))) noprint;
  var x_q1&yr2 x_q2&yr2 x_q3&yr2 x_q4&yr2;
  by country;
  output out=_79_&yr2 sum=;
run;
****************************************;
**GIVE COMBO SIC CODE FOR ABOVE GROUPS**;
****************************************;
data xlevel&yr2;
  set xlevel&yr2
      _12_&yr2(in=sic0102)
      _79_&yr2(in=sic0709);
  if sic0102=1 then siccode=102;
  if sic0709=1 then siccode=709;
run;
proc sort data=xlevel&yr2;
  by siccode country;
run;


****************************************************;
**PULL IN QUARTERLY  EXPORT LEVELS 19&yr1 FROM ITC**;
****************************************************;
data xlevel&yr1;
  infile in(SIC_2DIGIT_QUART_&yr1..TXT) firstobs=3 dlm=",";
  input country $ siccode x_q1&yr1 x_q2&yr1 x_q3&yr1 x_q4&yr1;
run;

proc sort data=xlevel&yr1;
  by country;
run;
***************************;
**COMBINE SIC01 and SIC02**;
***************************;
proc means data=xlevel&yr1(where=(siccode in(1,2))) sum noprint;
  var x_q1&yr1 x_q2&yr1 x_q3&yr1 x_q4&yr1;
  by country;
  output out=_12_&yr1 sum=;
run;

*********************************;
**COMBINE SIC07,SIC08 AND SIC09**;
*********************************;
proc means data=xlevel&yr1(where=(siccode in(7,8,9))) sum noprint;
  var x_q1&yr1 x_q2&yr1 x_q3&yr1 x_q4&yr1;
  by country;
  output out=_79_&yr1 sum=;
run;

****************************************;
**GIVE COMBO SIC CODE FOR ABOVE GROUPS**;
****************************************;
data xlevel&yr1;
  set xlevel&yr1
      _12_&yr1(in=sic0102)
      _79_&yr1(in=sic0709);
  if sic0102=1 then siccode=102;
  if sic0709=1 then siccode=709;
run;

proc sort data=xlevel&yr1;
  by siccode country;
run;


%macro quarter;
%do i = 1 %to 4;
**************************************************************;
**CREATE NOMINAL CHANGE IN X LEVELS FOR INDIVIDUAL COUNTRIES**;
**************************************************************;
data xlevels;
  merge xlevel&yr1 xlevel&yr2;
  by siccode country;
  if 100>siccode>39 or siccode="." then delete;
  nom_chg = ((x_q&i.&yr2/x_q&i.&yr1)-1)*100;
run;

***********************************************************;
**CREATE REAL CHANGE IN X LEVELS FOR INDIVIDUAL COUNTRIES**;
**  Use deflated export price indices to create real.    **;
***********************************************************;
proc sort data=xlevels;
  by siccode country;
run;
data deflate;
  merge xlevels(drop=nom_chg) out.xprice(where=(siccode<>0));
  by siccode;
  real_y&yr2 = (x_q&i.&yr2/(q&i._&yr2/100));
  real_y&yr1 = (x_q&i.&yr1/(q&i._&yr1/100));
  real_chg = ((real_y&yr2/real_y&yr1)-1)*100;
  if 100>siccode>39 or siccode="." then delete;
run;

*******************************************************;
**PRINT REAL EXPORT LEVELS BY COUNTRY FROM USITC     **;
*******************************************************;
proc print data=deflate noobs;
  var siccode country x_q&i.&yr2 q&i._&yr2 real_y&yr2 x_q&i.&yr1 q&i._&yr1 real_y&yr1;
  title "Real Export Levels";
  title2 "By Country, From 19&yr1 to 19&yr2, Quarter &i";
run;

proc sort data=deflate;
  by siccode;
run;
**********************************************************;
**PREPARE TO GROUP COUNTRIES USING NOMINAL EXPORT LEVELS**;
**********************************************************;
proc transpose data=deflate out=real_c;
  by siccode;
  var real_chg;
  id country;
run;

*******************************************************;
**PRINT REAL EXPORT CHANGE BY COUNTRY FROM USITC     **;
*******************************************************;
proc print data=real_c noobs;
  title "Real Export Changes- yoy";
  title2 "By Country, From 19&yr1 to 19&yr2, Quarter &i";
run;


********************************************;
**GROUP COUNTRIES USING REAL EXPORT LEVELS**;
********************************************;
**Country group 4  (Asian 10) -- Indonesia, Malaysia, Philippines, Korea, Thailand, Hong_Kong, Singapore, Taiwan, China, Japan;
   proc means data=deflate
      (where=(country in ("Indonesi","Malaysia","Philippi","Korea","Thailand","Hong_Kon",
                          "Singapor","Taiwan","China","Japan")))  sum noprint;
     var real_y&yr2 real_y&yr1;
     class siccode;
     output out=group4 sum=rel_g4&yr2 rel_g4&yr1;
     title "Group 4";
   run;

******************************************************;
**CREATE REAL CHANGE IN X LEVELS FOR COUNTRY GROUPS **;
******************************************************;
data groupchg(keep=siccode group4);
  set group4;
  group4 = ((rel_g4&yr2/rel_g4&yr1)-1)*100;
run;

data real&i(drop=_name_);
  merge real_c groupchg;
  by siccode;
  if siccode="." then delete;
run;

*****************************************;
**PRINT REAL EXPORT CHANGE BY GROUP    **;
*****************************************;
proc print data=real&i noobs;
  var siccode group1 group2 group3 group4;
  title "Real Percent Changes-YOY";
  title2 "By group, From 19&yr1 TO 19&yr2, Quarter &i" ;
run;
%end;
%mend;
%quarter;

*******************************************************;
**GET RID OF INDIVIDUAL SIC01,02,08,09 AND COMBO 1112**;
*******************************************************;
data real;
  merge real1(rename=(group4=qtr1)) real2(rename=(group4=qtr2))
        real3(rename=(group4=qtr3)) real4(rename=(group4=qtr4));
  by siccode;
  if siccode in(1112,1,2,8,9) then delete;
run;

****************************************;
**CREATE QUARTERLY COLUMNS FOR TABLE 5**;
**  Group 4 only                      **;
****************************************;
proc print data=real noobs;
  var siccode qtr1 qtr2 qtr3 qtr4;
  title "Table 5 - Quarterly";
  title2 " U.S. Real Exports to East Asia by Industry";
  title3 "(percent change from year ago, &yr1 to &yr2)";
  footnote "Sources:  U.S. Department of Commerce, Bureau of the Census.  U.S. Department of Labor,";
  footnote2 "Bureau of Labor Statistics.";
run;

****************************************************;
**CONVERT CHARACTER TO NUMERIC SIC FOR MERGE BELOW**;
****************************************************;
data x_out_&goyr;
  set out.x_out_&goyr;
  siccode=1*sic;
run;
proc sort data=x_out_&goyr;
  by siccode;
run;

******************************************;
**CREATE YEAR TO DATE VALUES FOR TABEL 7**;
**  Group 4 only                        **;
******************************************;
proc sort data=real;
  by siccode;
run;
data table7;
  merge real x_out_&goyr;
  by siccode;
  t7qtr1=qtr1*ratio4;
  t7qtr2=qtr2*ratio4;
  t7qtr3=qtr3*ratio4;
  t7qtr4=qtr4*ratio4;
run;

*****************************************;
**PRINT YEAR TO DATE COLUMN FOR TABEL 7**;
**  Group 4 only                       **;
*****************************************;
proc print data=table7 noobs;
  var siccode t7qtr1 t7qtr2 t7qtr3 t7qtr4;
  title "Table 7 - Quarterly";
  title2 " Export Effect on Growth by Industry - Gross Output(&goyr) Basis";
  title3 "(percent, &yr1 to &yr2)";
  footnote "Sources:  U.S. Department of Commerce, Bureau of the Census.  U.S. Department of Labor,";
  footnote2 "Bureau of Labor Statistics.";
run;

